<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>QEyesConfigDialog</name>
    <message>
        <location filename="../qeyesconfigdialog.cpp" line="44"/>
        <source>Appearance</source>
        <translation>Ulkoasu</translation>
    </message>
    <message>
        <location filename="../qeyesconfigdialog.cpp" line="50"/>
        <source>Number of eyes</source>
        <translation>Silmien määrä</translation>
    </message>
    <message>
        <location filename="../qeyesconfigdialog.cpp" line="56"/>
        <source>Type</source>
        <translation>Tyyppi</translation>
    </message>
    <message>
        <location filename="../qeyesconfigdialog.cpp" line="60"/>
        <source>Close</source>
        <translation>Sulje</translation>
    </message>
    <message>
        <location filename="../qeyesconfigdialog.cpp" line="65"/>
        <source>Reset</source>
        <translation>Palauta</translation>
    </message>
    <message>
        <location filename="../qeyesconfigdialog.cpp" line="69"/>
        <source>QEyes Settings</source>
        <translation>QEyesin asetukset</translation>
    </message>
    <message>
        <location filename="../qeyesconfigdialog.cpp" line="103"/>
        <source>QEyes default</source>
        <translation>QEyesin oletus</translation>
    </message>
</context>
</TS>
